@@ -125,7 +125,9 @@ class SaltFactoriesManager(object):
             "proxy_minions": {},
             "daemons": {},
         }
-        self.event_listener = event_listener.EventListener()
+        self.event_listener = event_listener.EventListener(
+            auth_events_callback=self._handle_auth_event
+        )
         self.event_listener.start()
 
     @staticmethod
@@ -888,7 +890,7 @@ class SaltFactoriesManager(object):
             **extra_daemon_class_kwargs
         )
 
-    def get_salt_cli(self, request, master_id, **cli_kwargs):
+    def get_salt_cli(self, master_id, **cli_kwargs):
         """
         Return a `salt` CLI process
         """
@@ -904,7 +906,7 @@ class SaltFactoriesManager(object):
             script_path, config=self.cache["masters"][master_id].config, **cli_kwargs
         )
 
-    def get_salt_call_cli(self, request, minion_id, **cli_kwargs):
+    def get_salt_call_cli(self, minion_id, **cli_kwargs):
         """
         Return a `salt-call` CLI process
         """
@@ -933,7 +935,7 @@ class SaltFactoriesManager(object):
                     "Could not find {} in the minions or proxy minions caches".format(minion_id)
                 )
 
-    def get_salt_run(self, request, master_id, **cli_kwargs):
+    def get_salt_run_cli(self, master_id, **cli_kwargs):
         """
         Return a `salt-run` CLI process
         """
@@ -949,7 +951,7 @@ class SaltFactoriesManager(object):
             script_path, config=self.cache["masters"][master_id].config, **cli_kwargs
         )
 
-    def get_salt_cp(self, request, master_id, **cli_kwargs):
+    def get_salt_cp_cli(self, master_id, **cli_kwargs):
         """
         Return a `salt-cp` CLI process
         """
@@ -965,7 +967,7 @@ class SaltFactoriesManager(object):
             script_path, config=self.cache["masters"][master_id].config, **cli_kwargs
         )
 
-    def get_salt_key(self, request, master_id, **cli_kwargs):
+    def get_salt_key_cli(self, master_id, **cli_kwargs):
         """
         Return a `salt-key` CLI process
         """
@@ -1072,3 +1074,12 @@ class SaltFactoriesManager(object):
             counter += 1
         root_dir.ensure(dir=True)
         return root_dir
+
+    def _handle_auth_event(self, master_id, payload):
+        self.pytestconfig.hook.pytest_saltfactories_handle_key_auth_event(
+            factories_manager=self,
+            master_id=master_id,
+            minion_id=payload["id"],
+            keystate=payload["act"],
+            payload=payload,
+        )
