@@ -50,13 +50,14 @@ class MinionFactory(object):
             "log_file": "logs/minion.log",
             "log_level_logfile": "debug",
             "loop_interval": 0.05,
-            "open_mode": True,
             #'multiprocessing': False,
             "log_fmt_console": "%(asctime)s,%(msecs)03.0f [%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
             "log_fmt_logfile": "[%(asctime)s,%(msecs)03.0f][%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
             "hash_type": "sha256",
             "transport": "zeromq",
             "pytest-minion": {"log": {"prefix": "salt-minion({})".format(minion_id)},},
+            "acceptance_wait_time": 0.5,
+            "acceptance_wait_time_max": 5,
         }
         # Merge in the initial default options with the internal _config_defaults
         salt.utils.dictupdate.update(config_defaults, _config_defaults, merge_lists=True)
