@@ -5,11 +5,11 @@ from __future__ import unicode_literals
 
 
 def pytest_saltfactories_master_configuration_overrides(
-    request, factories_manager, default_options, master_id
+    request, factories_manager, config_defaults, master_id
 ):
     """
     Hook which should return a dictionary tailored for the provided master_id.
-    This dictionary will override the default_options dictionary.
+    This dictionary will override the config_defaults dictionary.
 
     Stops at the first non None result
     """
