@@ -34,6 +34,11 @@ def test_generate_script_defaults(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_foobar
         import salt.utils.platform
@@ -82,6 +87,11 @@ def test_generate_script_executable(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_foobar
         import salt.utils.platform
@@ -130,6 +140,11 @@ def test_generate_script_long_executable(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_foobar
         import salt.utils.platform
@@ -175,6 +190,11 @@ def test_generate_script_code_dir(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         CODE_DIR = r'{}'
         if CODE_DIR in sys.path:
             sys.path.remove(CODE_DIR)
@@ -233,6 +253,11 @@ def test_generate_script_inject_coverage(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         CODE_DIR = r'{}'
         if CODE_DIR in sys.path:
             sys.path.remove(CODE_DIR)
@@ -298,6 +323,11 @@ def test_generate_script_inject_sitecustomize(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         CODE_DIR = r'{}'
         if CODE_DIR in sys.path:
             sys.path.remove(CODE_DIR)
@@ -368,6 +398,11 @@ def test_generate_script_inject_sitecustomize(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         # Allow sitecustomize.py to be importable for test coverage purposes
         SITECUSTOMIZE_DIR = r'{}'
         PYTHONPATH = os.environ.get('PYTHONPATH') or None
@@ -430,6 +465,11 @@ def test_generate_script_salt(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_main
 
@@ -466,6 +506,11 @@ def test_generate_script_salt_api(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         import salt.cli
 
@@ -506,6 +551,11 @@ def test_generate_script_creates_missing_bin_dir(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_foobar
         import salt.utils.platform
@@ -553,6 +603,11 @@ def test_generate_script_only_generates_once(tmpdir):
         import os
         import sys
 
+        # We really do not want buffered output
+        os.environ[str("PYTHONUNBUFFERED")] = str("1")
+        # Don't write .pyc files or create them in __pycache__ directories
+        os.environ[str("PYTHONDONTWRITEBYTECODE")] = str("1")
+
         import atexit
         from salt.scripts import salt_foobar
         import salt.utils.platform
